import React, {createContext, useReducer, useEffect} from 'react';
import {AppReducer} from "./appReducer";

export const AppContext = createContext();

const AppContextProvider = ({baseTitle, children}) => {
    const initialAppState = {
        title: baseTitle,
        selectedMenu: 'home',
        pageData: {}
    };
    const [state, dispatch] = useReducer(AppReducer, initialAppState)

    const setTitle = payload => {
        dispatch({type: 'SET_TITLE', payload})
    }

    const setSelectedMenu = payload => {
        dispatch({type: 'SET_SELECTED_MENU', payload})
    }

    const setPageData = (pageId, payload) => {
        dispatch({type: 'SET_PAGE_DATA', pageId, payload});
    }

    /**
     * clenup code, return in useEffect
     */
    const cleanupStateOnDidUnmount = () => {
        setTitle(initialAppState.title);
        setSelectedMenu(initialAppState.selectedMenu);
    }

    const contextValues = {
        setTitle,
        setSelectedMenu,
        setPageData,
        cleanupStateOnDidUnmount,
        ...state
    }

    return (
        <AppContext.Provider value={contextValues}>
            {children}
        </AppContext.Provider>
    );
}

export default AppContextProvider